@@ -28,19 +28,23 @@ Free Software Foundation, Inc.,
 #endif
 
 #include <QAbstractListModel>
+#include <QQmlParserStatus>
 
 class QMimeData;
 
-class PagerModel : public QAbstractListModel
+class PagerModel : public QAbstractListModel, public QQmlParserStatus
 {
     Q_OBJECT
 
+    Q_INTERFACES(QQmlParserStatus)
+
     Q_ENUMS(PagerType)
     Q_ENUMS(AdditionalRoles)
 
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
     Q_PROPERTY(PagerType pagerType READ pagerType WRITE setPagerType NOTIFY pagerTypeChanged)
     Q_PROPERTY(bool enabled READ enabled WRITE setEnabled NOTIFY enabledChanged)
+    Q_PROPERTY(bool shouldShowPager READ shouldShowPager NOTIFY shouldShowPagerChanged);
     Q_PROPERTY(bool showDesktop READ showDesktop WRITE setShowDesktop NOTIFY showDesktopChanged)
     Q_PROPERTY(bool showOnlyCurrentScreen READ showOnlyCurrentScreen WRITE setShowOnlyCurrentScreen NOTIFY showOnlyCurrentScreenChanged)
     Q_PROPERTY(QRect screenGeometry READ screenGeometry WRITE setScreenGeometry NOTIFY screenGeometryChanged)
@@ -73,6 +77,8 @@ public:
     bool enabled() const;
     void setEnabled(bool enabled);
 
+    bool shouldShowPager() const;
+
     bool showDesktop() const;
     void setShowDesktop(bool show);
 
@@ -100,10 +106,14 @@ public:
     Q_INVOKABLE void addDesktop();
     Q_INVOKABLE void removeDesktop();
 
+    void classBegin();
+    void componentComplete();
+
 Q_SIGNALS:
     void countChanged() const;
     void pagerTypeChanged() const;
     void enabledChanged() const;
+    void shouldShowPagerChanged() const;
     void showDesktopChanged() const;
     void showOnlyCurrentScreenChanged() const;
     void screenGeometryChanged() const;
